@@ -3,6 +3,7 @@ from argparse import Namespace
 from functools import lru_cache
 
 from flake8.options.manager import OptionManager
+
 from flake8_annotations import (
     Argument,
     Function,
@@ -18,7 +19,7 @@ from flake8_annotations import (
 if PY_GTE_38:
     import ast
 else:
-    from typed_ast import ast3 as ast
+    from typed_ast import ast3 as ast  # type: ignore[no-redef]
 
 FORMATTED_ERROR = t.Tuple[int, int, str, t.Type[t.Any]]
 
